#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
from mongoengine import *
from datetime import datetime, date, timedelta


class SampleDocumentSameName(Document):
    name = StringField(max_length=255, required=True, unique=True)
    date = StringField(required=True)
    flag = BooleanField(default=False)


class SampleDocumentNotSameName(Document):
    name = StringField(max_length=255, required=True, unique=True)
    _date_str = StringField(db_field='date_str', max_length=20, required=True)
    flag = BooleanField(default=False)

    def __init__(self, *args, **kwargs):
        rd = kwargs.pop("date", datetime.utcnow())
        Document.__init__(self, *args, **kwargs)
        self.date = rd

    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = datetime(value.year, value.month, value.day)
        self._date_str = self._date.isoformat()

print '='*30
connect('r2d2_local')

today = date.today()
yesterday = today - timedelta(days=1)

print '====SampleDocumentSameName===='
SampleDocumentSameName.objects.delete()
doc = SampleDocumentSameName(name='hello', date=yesterday.isoformat())
doc.save()
doc.reload()
print doc.date
doc.date = today.isoformat()
doc.flag = not doc.flag
doc.save()
doc.reload()
print doc.date

print '----SampleDocumentNotSameName----'
SampleDocumentNotSameName.objects.delete()
print yesterday
doc = SampleDocumentNotSameName(name='hello', date=yesterday)
doc.save()
doc.reload()
print doc._date_str
doc.date = today
doc.flag = not doc.flag
doc.save()
doc.reload()
print doc._date_str
